# Ravop
Op is the fundamental unit of Ravenverse. Ravop is our library to work with ops. You can create ops, interact with ops, and create scalars and tensors. Ravop is a crucial building block of the framework. It can be used to write various algorithms, formulas, and mathematical calculations.

### Documentation
    
[Ravop documentation](https://ravenprotocol.gitbook.io/ravenverse/ravop)

#### Create a .env file and put the following credentials there:

    RAVENVERSE_HOST=0.0.0.0
    RAVENVERSE_PORT=9999
    RAVENVERSE_FTP_HOST=0.0.0.0

### License

<a href="https://github.com/ravenprotocol/ravop/blob/main/LICENSE.rst"><img src="https://img.shields.io/github/license/ravenprotocol/ravop"></a>

This project is licensed under the MIT License - see the [LICENSE](LICENSE) file for details